/**
   \file com/st/p2012/mind/ast/CommentDecoration.java
   \brief A final class for accessing comment decorations in the semantic AST.


   <B>
   \n
   This file is part of the Platform 2012 program,
   a cooperation between STMicroelectronics and CEA.\n
   Redistribution of this file to outside parties is
   strictly prohibited without the written consent
   of the module owner indicated below.\n
   </B>

   \par  Module owner: michel.metzger@st.com


   \par  Copyright (C) 2009 STMicroelectronics

   \par  Authors: ali-erdem.ozcan@st.com

   \par  Id: $Id$
   \par  Date: $Date$
   \par  Revision: $Rev$

 */

package com.st.p2012.mind.ast;

import org.objectweb.fractal.adl.Node;

public final class CommentDecoration {
  private CommentDecoration() {
  }

  public final static String COMMENT_DECORATION       = "comment";
  public final static String SHORT_COMMENT_DECORATION = "short_comment";

  public static void setComment(final Node node, final String comment) {
    if (comment != null) {
      node.astSetDecoration(COMMENT_DECORATION, comment);
    }
  }

  public static void setShortComment(final Node node, final String comment) {
    if (comment != null) {
      node.astSetDecoration(SHORT_COMMENT_DECORATION, comment);
    }
  }

  public static String getComment(final Node node) {
    return (String) node.astGetDecoration(COMMENT_DECORATION);
  }

  public static String getShortComment(final Node node) {
    return (String) node.astGetDecoration(SHORT_COMMENT_DECORATION);
  }

}
