/**
 \file com/st/p2012/mind/comments/FigureTag.java
 \brief A class to represent a "@figure" tag in a comment.

 <B>
 \n
 This file is part of the Platform 2012 program,
 a cooperation between STMicroelectronics and CEA.\n
 Redistribution of this file to outside parties is
 strictly prohibited without the written consent
 of the module owner indicated below.\n
 </B>

 \par  Module owner: michel.metzger@st.com


 \par  Copyright (C) 2009 STMicroelectronics

 \par  Authors: michel.metzger@st.com

 \par  Id: $Id$
 \par  Date: $Date$
 \par  Revision: $Rev$

 */

package com.st.p2012.mind.comments;

import static com.st.p2012.mind.Launcher.DOC_FILES_DIRECTORY;

import java.io.File;

import com.st.p2012.mind.HTMLDocumentationHelper.SourceKind;

public class FigureTag extends CommentTag {

  public final String path;
  public int width  = -1;
  public int height = -1;


  protected FigureTag(final String path, final int beginIndex, final int endIndex) {
    super(beginIndex, endIndex);
    this.path = path;
  }

  public void setWidth(final int width) {
    this.width = width;
  }

  public void setHeight(final int height) {
    this.height = height;
  }

  public String getPath() {
    return path;
  }

  public int getHeight() {
    return height;
  }

  public int getWidth() {
    return width;
  }

  @Override
  public String getReplacement(final String definitionName, final SourceKind sourceKind) {
    String sizeString = "";
    if(width != -1) {
      sizeString = String.format("width=\"%dpx\"", width);
    } else if(height != -1) {
      sizeString = String.format("height=\"%dpx\"", height);
    }
    return String.format("<img src=\"%s\" class=\"figure\" %s/>",
        DOC_FILES_DIRECTORY + File.separatorChar + path, sizeString);
  }

}
