/**
 \file com/st/p2012/mind/comments/LinkInterfaceTag.java
 \brief A class to represent a "@interface" tag in a comment.


 <B>
 \n
 This file is part of the Platform 2012 program,
 a cooperation between STMicroelectronics and CEA.\n
 Redistribution of this file to outside parties is
 strictly prohibited without the written consent
 of the module owner indicated below.\n
 </B>

 \par  Module owner: michel.metzger@st.com


 \par  Copyright (C) 2009 STMicroelectronics

 \par  Authors: michel.metzger@st.com

 \par  Id: $Id$
 \par  Date: $Date$
 \par  Revision: $Rev$

 */

package com.st.p2012.mind.comments;

import static com.st.p2012.mind.HTMLDocumentationHelper.getRelativeLinkToEnum;
import static com.st.p2012.mind.HTMLDocumentationHelper.getRelativeLinkToMethod;
import static com.st.p2012.mind.HTMLDocumentationHelper.getRelativeLinkToStruct;
import static com.st.p2012.mind.HTMLDocumentationHelper.getRelativeLinkToTypedef;
import static com.st.p2012.mind.HTMLDocumentationHelper.getRelativeLinkToUnion;
import static com.st.p2012.mind.HTMLDocumentationHelper.getRelativePathToITF;

import com.st.p2012.mind.HTMLDocumentationHelper;
import com.st.p2012.mind.HTMLDocumentationHelper.SourceKind;
import com.st.p2012.mind.comments.LinkTag.InterfaceLinkElementType;

public class LinkInterfaceTag extends LinkTag<InterfaceLinkElementType> {

  public LinkInterfaceTag(final String target, final String subElemType, final String subElemName,
      final int beginIndex, final int endIndex) throws CommentParserException {
    super(target, subElemType, subElemName, beginIndex, endIndex);
    if(this.subElemType == InterfaceLinkElementType.TYPES && subElemName != null) {
      throw new CommentParserException();
    } else if(this.subElemType != null) {
      if(this.subElemType != InterfaceLinkElementType.TYPES && this.subElemType != InterfaceLinkElementType.METHODS && subElemName == null) {
        throw new CommentParserException();
      }
    }
  }

  @Override
  protected InterfaceLinkElementType parseSubElemType(final String type) {
    return InterfaceLinkElementType.valueOf(type.toUpperCase());
  }

  @Override
  protected String getSubElemHref(final String definitionName, final HTMLDocumentationHelper.SourceKind sourceKind) {
    switch (getSubElemType()) {
      case ENUMS: return getRelativeLinkToEnum(definitionName, getTarget(), getSubElemName(), sourceKind);
      case STRUCTS: return getRelativeLinkToStruct(definitionName, getTarget(), getSubElemName(), sourceKind);
      case UNIONS: return getRelativeLinkToUnion(definitionName, getTarget(), getSubElemName(), sourceKind);
      case TYPEDEFS: return getRelativeLinkToTypedef(definitionName, getTarget(), getSubElemName(), sourceKind);
      case METHODS: return getRelativeLinkToMethod(definitionName, getTarget(), getSubElemName(), sourceKind);
      default: return "";
    }
  }

  @Override
  protected String getSubElemTypeHref(final String definitionName,
      final SourceKind sourceKind) {
    switch (getSubElemType()) {
      case METHODS: return HTMLDocumentationHelper.getRelativeLinkToMethodSection(definitionName, getTarget(), sourceKind);
      case TYPES: return HTMLDocumentationHelper.getRelativeLinkToTypeSection(definitionName, getTarget(), sourceKind);
      default: return "";
    }
  }

  @Override
  protected String getTargetHref(final String definitionName, final HTMLDocumentationHelper.SourceKind sourceKind) {
    return getRelativePathToITF(definitionName, getTarget(), sourceKind);
  }

  @Override
  protected String getSubElemLabel() {
    switch (getSubElemType()) {
      case ENUMS: return "enum";
      case STRUCTS: return "struct";
      case UNIONS: return "union";
      case TYPEDEFS: return "typedef";
      case METHODS: return "method";
      default: return "";
    }
  }


}
